@@ -41,12 +41,12 @@ The library exposes the following functions:
 
 .. autofunction:: edr_to_dict
 """
-import xdrlib
+from mda_xdrlib import xdrlib
 import collections
 import warnings
 import sys
 import itertools
-import time
+from tqdm import tqdm
 from typing import List, Tuple, Dict
 
 import numpy as np
@@ -439,30 +439,15 @@ def read_edr(path: str, verbose: bool = False) -> read_edr_return_type:
     times: list[float]
         A list containing the time of each step/frame.
     """
-    begin = time.time()
     edr_file = EDRFile(str(path))
     all_energies = []
     all_names = [u'Time'] + [nm.name for nm in edr_file.nms]
     times = []
-    for ifr, frame in enumerate(edr_file):
-        if verbose:
-            if ((ifr < 20 or ifr % 10 == 0) and
-                    (ifr < 200 or ifr % 100 == 0) and
-                    (ifr < 2000 or ifr % 1000 == 0)):
-                print('\rRead frame : {},  time : {} ps'.format(ifr, frame.t),
-                      end='', file=sys.stderr)
+    for ifr, frame in tqdm(enumerate(edr_file), disable=(not verbose)):
         if frame.ener:
             # Export only frames that contain energies
             times.append(frame.t)
             all_energies.append([frame.t] + [ener.e for ener in frame.ener])
-
-    end = time.time()
-    if verbose:
-        print('\rLast Frame read : {}, time : {} ps'
-              .format(ifr, frame.t),
-              end='', file=sys.stderr)
-        print('\n{} frame read in {:.2f} seconds'.format(ifr, end - begin),
-              file=sys.stderr)
     return all_energies, all_names, times
 
 
